@@ -541,11 +541,11 @@ class BaseInlineFormSetWithAddMoreButton(BaseInlineFormSet):
                     </div>
                     <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.3.1/jquery.min.js"></script>
 <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.12.9/umd/popper.min.js"></script>
-<script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/js/bootstrap.min.js">
+<script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/js/bootstrap.min.js"></script>
         <script>
     $('#{button_id}').click(function() {{
         var form_idx = $('#id_{self.prefix}-TOTAL_FORMS').val();
-        var empty_form = document.getElementById('{empty_form_id}).innerHTML.replace(/__prefix__/g, form_idx);        
+        var empty_form = document.getElementById('{empty_form_id}').innerHTML.replace(/__prefix__/g, form_idx);        
         var d1 = document.getElementById('{div_name}');
         d1.insertAdjacentHTML('afterend', empty_form);
         $('#id_{self.prefix}-TOTAL_FORMS').val(parseInt(form_idx) + 1);
@@ -595,7 +595,7 @@ class DataTransform(forms.ModelForm):
                               'id': str(uuid.uuid4())}],
                     prefix=str(self.instance.id) + 'dataTransformerInlineFormset'
                 )
-                self.nested_data_transformer_form.extra = self.instance.get_children().count() + 1
+                self.nested_data_transformer_form.extra = 0
 
 
         except Exception as e:
@@ -617,7 +617,8 @@ class DataTransform(forms.ModelForm):
             initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
-        self.nested_constants_form.extra = self.instance.datatransformerconstants_set.count() + 1
+        self.nested_constants_form.extra = 0
+        # self.nested_constants_form.extra = self.instance.datatransformerconstants_set.count() + 1
 
         hardware_outputs = self.instance.hardwaredatatransformer_set.first()
         self.nested_hardware_outputs_form = HardwareTransformerForm(
@@ -637,7 +638,7 @@ class DataTransform(forms.ModelForm):
             initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
-        self.nested_hardware_stats_form.extra = self.instance.hardwarestatsdatatransformer_set.count() + 1
+        self.nested_hardware_stats_form.extra = 0
 
     def as_p(self):
         print('wtf')
@@ -706,7 +707,8 @@ class DataTransform(forms.ModelForm):
 dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
                                                      fk_name='parent',
                                                      can_delete_extra=True,
-                                                     form=DataTransform
+                                                     form=DataTransform,
+                                                     formset=BaseInlineFormSetWithAddMoreButton
                                                      )
 
 
@@ -737,7 +739,7 @@ class DataTransformRoot(forms.ModelForm):
                               'id': str(uuid.uuid4())}],
                     prefix=str(self.instance.id) + 'dataTransformerInlineFormset',
                 )
-                self.nested_data_transformer_form.extra = self.instance.get_children().count() + 1
+                self.nested_data_transformer_form.extra = 0
 
             else:
 
@@ -760,7 +762,7 @@ class DataTransformRoot(forms.ModelForm):
             initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
-        self.nested_constants_form.extra = self.instance.datatransformerconstants_set.count() + 1
+        self.nested_constants_form.extra = 0
 
         hardware_outputs = self.instance.hardwaredatatransformer_set.first()
         self.nested_hardware_outputs_form = HardwareTransformerForm(
@@ -780,7 +782,7 @@ class DataTransformRoot(forms.ModelForm):
             initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
-        self.nested_hardware_stats_form.extra = self.instance.hardwarestatsdatatransformer_set.count() + 1
+        self.nested_hardware_stats_form.extra = 0
 
     def as_p(self):
         print('root')
